@@ -1,11 +1,11 @@
 /*
  *  agShell
- *  $Id: agShell.c,v 1.33 2003/11/08 19:32:06 bkorb Exp $
+ *  $Id: agShell.c,v 4.1 2005/01/01 00:12:17 bkorb Exp $
  *  Manage a server shell process
  */
 
 /*
- *  AutoGen copyright 1992-2003 Bruce Korb
+ *  AutoGen copyright 1992-2004 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -83,9 +83,6 @@ closeServer( void )
 STATIC void
 sigHandler( int signo )
 {
-#ifndef HAVE_STRSIGNAL
-    extern char* strsignal PROTO(( int ));
-#endif
     fprintf( pfTrace, "Closing server:  %s signal (%d) received\n",
              strsignal( signo ), signo );
     errClose = AG_TRUE;
@@ -111,8 +108,12 @@ serverSetup( void )
     {
         static int doneOnce = 0;
         if (doneOnce++ == 0) {
+            char* p = malloc( MAXPATHLEN );
+            if (p == NULL)
+                AG_ABEND( "cannot allocate path name" );
+
             (void)atexit( &closeServer );
-            pCurDir = getcwd( NULL, MAXPATHLEN+1 );
+            pCurDir = (tpChar)getcwd( p, MAXPATHLEN );
 #if defined( DEBUG_ENABLED )
             if (HAVE_OPT( SHOW_SHELL ))
                 fputs( "\nServer First Start\n", pfTrace );
@@ -141,24 +142,27 @@ serverSetup( void )
                 "&& (emulate sh) >/dev/null 2>&1\n"
             "then\n"
             "  emulate sh\n"
-            "  NULLCMD=:\n"
-            "else if test -n \"${BASH_VERSION+set}\" "
-                  "&& (set -o posix) >/dev/null 2>&1\n"
+            "  NULLCMD=:\n\n"
+            "else\n  if test -n \"${BASH_VERSION+set}\" "
+                       "&& (set -o posix) >/dev/null 2>&1\n"
             "then\n"
             "  set -o posix\n"
             "fi ; fi\n"
 
             "for f in 1 2 5 6 7 13 14\n"
             "do trap \"echo trapped on $f >&2\" $f 2>/dev/null\n"
-            "done\n" "unalias cd 2>/dev/null >&2\n" "AG_pid=\000.........\n";
+            "done\n"
+            "test -n \"${CDPATH}\" && { CDPATH=''\n"
+            "  unset CDPATH 2>&null\n}\n"
+            "unalias cd 2>/dev/null >&2\n"
+            "AG_pid=\000.........\n";
         static char* pzPid = NULL;
         char* pz;
         pzLastCmd = zTrap;
         if (pzPid == NULL)
             pzPid = zTrap + strlen( zTrap );
         sprintf( pzPid, "%d\n", getpid() );
-        fprintf( serverPair.pfWrite, zCmdFmt, pCurDir,
-                 pzLastCmd, zShDone );
+        fprintf( serverPair.pfWrite, zCmdFmt, pCurDir, pzLastCmd, zShDone );
         (void)fflush( serverPair.pfWrite );
         pz = loadData( serverPair.pfRead );
 #if defined( DEBUG_ENABLED )
