@@ -1,7 +1,7 @@
 
 /*
  *  autogen.h
- *  $Id: autogen.h,v 1.60 2004/10/11 23:30:00 bkorb Exp $
+ *  $Id: autogen.h,v 4.1 2005/01/01 00:12:17 bkorb Exp $
  *  Global header file for AutoGen
  */
 
@@ -30,10 +30,6 @@
 #include "config.h"
 #include "compat/compat.h"
 
-#if defined(HAVE_FOPENCOOKIE) || defined(HAVE_FUNOPEN)
-#  define ENABLE_FMEMOPEN
-#endif
-
 #include REGEX_HEADER
 #include <guile/gh.h>
 
@@ -468,7 +464,11 @@ MODE v2c_t p2p VALUE( { NULL } );
 #else
 # define AG_ABEND(s)  ag_abend(s)
 #endif
-#undef  DEBUG
+#ifdef DEBUG_FSM
+# define DEBUG
+#else
+# undef  DEBUG
+#endif
 
 #define AG_ABEND_IN(t,m,s) \
     STMTS( pCurTemplate=(t); pCurMacro=(m); AG_ABEND(s);)
