@@ -1,12 +1,11 @@
 /*
- *  $Id: defFind.c,v 1.22 2003/02/15 22:58:59 bkorb Exp $
- *  This module loads the definitions, calls yyparse to decipher them,
- *  and then makes a fixup pass to point all children definitions to
- *  their parent definition (except the fixed "rootEntry" entry).
+ *  $Id: defFind.c,v 4.1 2005/01/01 00:12:33 bkorb Exp $
+ *
+ *  This module locates definitions.
  */
 
 /*
- *  AutoGen copyright 1992-2003 Bruce Korb
+ *  AutoGen copyright 1992-2004 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -24,8 +23,6 @@
  *             59 Temple Place - Suite 330,
  *             Boston,  MA  02111-1307, USA.
  */
-#include "autogen.h"
-#include "assert.h"
 
 struct defEntryList {
     size_t         allocCt;
@@ -190,8 +187,6 @@ badName( char* pzD, const char* pzS, size_t srcLen )
 EXPORT int
 canonicalizeName( char* pzD, const char* pzS, int srcLen )
 {
-    tSCC zNil[] = "";
-
     typedef enum {
         CN_START_NAME = 0,   /* must find a name */
         CN_NAME_ENDED,       /* must find '[' or '.' or we end */
@@ -374,7 +369,7 @@ canonicalizeName( char* pzD, const char* pzS, int srcLen )
  *  to traverse the list of twins).
  */
 STATIC tDefEntry*
-defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
+defEntrySearch( char* pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed )
 {
     char*        pcBrace;
     char         breakCh;
@@ -415,7 +410,7 @@ defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
          *  IF we are at the end of the definitions (reached ROOT),
          *  THEN it is time to bail out.
          */
-        pE = pDefStack->pDefs;
+        pE = pDefCtx->pDefs;
         if (pE == NULL)
             return NULL;
 
@@ -440,8 +435,8 @@ defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
         /*
          *  Let's go try the definitions at the next higher level.
          */
-        pDefStack = pDefStack->pPrev;
-        if (pDefStack == NULL)
+        pDefCtx = pDefCtx->pPrev;
+        if (pDefCtx == NULL)
             return NULL;
     } found_def_entry:;
 
@@ -515,14 +510,14 @@ defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
      */
     nestingDepth++;
     {
-        tDefStack stack = { NULL, &currDefCtx };
+        tDefCtx ctx = { NULL, &currDefCtx };
 
-        stack.pDefs = (tDefEntry*)pE->pzValue;
+        ctx.pDefs = pE->val.pDefEntry;
 
         for (;;) {
             tDefEntry* res;
 
-            res = defEntrySearch( pzName, &stack, pIsIndexed );
+            res = defEntrySearch( pzName, &ctx, pIsIndexed );
             if ((res != NULL) || (breakCh == '[')) {
                 nestingDepth--;
                 return res;
@@ -530,7 +525,7 @@ defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
             pE = pE->pTwin;
             if (pE == NULL)
                 break;
-            stack.pDefs = (tDefEntry*)pE->pzValue;
+            ctx.pDefs = pE->val.pDefEntry;
         }
     }
 
@@ -556,7 +551,7 @@ findDefEntry( char* pzName, ag_bool* pIsIndexed )
  *  not try to traverse the list of twins).
  */
 STATIC tDefEntry**
-entryListSearch( char* pzName, tDefStack* pDefStack )
+entryListSearch( char* pzName, tDefCtx* pDefCtx )
 {
     static tDefEntryList defList = { 0, 0, NULL, 0 };
 
@@ -591,7 +586,7 @@ entryListSearch( char* pzName, tDefStack* pDefStack )
          *  IF we are at the end of the definitions (reached ROOT),
          *  THEN it is time to bail out.
          */
-        pE = pDefStack->pDefs;
+        pE = pDefCtx->pDefs;
         if (pE == NULL) {
             /*
              *  Make sure we are not nested.  Once we start to nest,
@@ -628,8 +623,8 @@ entryListSearch( char* pzName, tDefStack* pDefStack )
         /*
          *  Let's go try the definitions at the next higher level.
          */
-        pDefStack = pDefStack->pPrev;
-        if (pDefStack == NULL)
+        pDefCtx = pDefCtx->pPrev;
+        if (pDefCtx == NULL)
             goto not_found;
     } found_def_entry:;
 
@@ -706,18 +701,18 @@ entryListSearch( char* pzName, tDefStack* pDefStack )
      */
     defList.nestLevel++;
     {
-        tDefStack stack = { NULL, &currDefCtx };
+        tDefCtx ctx = { NULL, &currDefCtx };
 
-        stack.pDefs = (tDefEntry*)pE->pzValue;
+        ctx.pDefs = pE->val.pDefEntry;
 
         for (;;) {
-            (void)entryListSearch( pzName, &stack );
+            (void)entryListSearch( pzName, &ctx );
             if (breakCh == '[')
                 break;
             pE = pE->pTwin;
             if (pE == NULL)
                 break;
-            stack.pDefs = (tDefEntry*)pE->pzValue;
+            ctx.pDefs = pE->val.pDefEntry;
         }
     }
     defList.nestLevel--;
@@ -737,7 +732,9 @@ findEntryList( char* pzName )
 }
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of defFind.c */
+ * end of agen5/defFind.c */
