@@ -1,7 +1,7 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (defParse-fsm.c)
  *  
- *  It has been AutoGen-ed  Tuesday May 18, 2004 at 08:49:08 PM PDT
+ *  It has been AutoGen-ed  Friday December 31, 2004 at 08:18:57 PM PST
  *  From the definitions    defParse.def
  *  and the template file   fsm
  *
@@ -458,6 +458,8 @@ dp_do_invalid(
 /*  START == INVALID == DO NOT CHANGE THIS COMMENT  */
     dp_invalid_transition( initial, trans_evt );
     yyerror( "invalid transition" );
+    /* NOTREACHED */
+    return DP_ST_INVALID;
 /*  END   == INVALID == DO NOT CHANGE THIS COMMENT  */
 }
 
@@ -632,4 +634,11 @@ dp_run_fsm( void )
     }
     return dp_state;
 }
-/* end of defParse-fsm.c */
+/*
+ * Local Variables:
+ * mode: C
+ * c-file-style: "stroustrup"
+ * tab-width: 4
+ * indent-tabs-mode: nil
+ * End:
+ * end of defParse-fsm.c */
