@@ -1,12 +1,12 @@
 
 /*
- *  $Id: funcFor.c,v 1.36 2003/02/28 21:33:11 bkorb Exp $
+ *  $Id: funcFor.c,v 4.1 2005/01/01 00:12:34 bkorb Exp $
  *
  *  This module implements the FOR text macro.
  */
 
 /*
- *  AutoGen copyright 1992-2003 Bruce Korb
+ *  AutoGen copyright 1992-2004 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -24,10 +24,6 @@
  *             59 Temple Place - Suite 330,
  *             Boston,  MA  02111-1307, USA.
  */
-#ifndef DEFINE_LOAD_FUNCTIONS
-
-#include "autogen.h"
-#include "expr.h"
 
 #define ENTRY_END  INT_MAX
 
@@ -57,7 +53,7 @@ doForEach( tTemplate*   pT,
  *          Outside of any FOR loop, it returns SCM_UNDEFINED.
  *          @xref{FOR}.
 =*/
-    SCM
+SCM
 ag_scm_first_for_p( SCM which )
 {
     if (forInfo.fi_depth <= 0)
@@ -67,11 +63,10 @@ ag_scm_first_for_p( SCM which )
         return (pFS->for_firstFor) ? SCM_BOOL_T : SCM_BOOL_F;
 
     {
-        size_t     ct;
         tForState* p   = forInfo.fi_data + (forInfo.fi_depth - 1);
-        char*      pz  = gh_scm2newstr( which, &ct );
+        char*      pz  = ag_scm2zchars( which, "which for" );
         SCM        res = SCM_UNDEFINED;
-        ct = forInfo.fi_depth;
+        int        ct  = forInfo.fi_depth;
 
         do  {
             if (strcmp( p->for_pzName, pz ) == 0) {
@@ -81,7 +76,6 @@ ag_scm_first_for_p( SCM which )
             p--;
         } while (--ct > 0);
 
-        free( (void*)pz );
         return res;
     }
 }
@@ -96,7 +90,7 @@ ag_scm_first_for_p( SCM which )
  *          Outside of any FOR loop, it returns SCM_UNDEFINED.
  *          @xref{FOR}.
 =*/
-    SCM
+SCM
 ag_scm_last_for_p( SCM which )
 {
     if (forInfo.fi_depth <= 0)
@@ -106,11 +100,10 @@ ag_scm_last_for_p( SCM which )
         return (pFS->for_lastFor ? SCM_BOOL_T : SCM_BOOL_F);
 
     {
-        size_t     ct;
         tForState* p   = forInfo.fi_data + (forInfo.fi_depth - 1);
-        char*      pz  = gh_scm2newstr( which, &ct );
+        char*      pz  = ag_scm2zchars( which, "which for" );
         SCM        res = SCM_UNDEFINED;
-        ct = forInfo.fi_depth;
+        int        ct  = forInfo.fi_depth;
 
         do  {
             if (strcmp( p->for_pzName, pz ) == 0) {
@@ -120,7 +113,6 @@ ag_scm_last_for_p( SCM which )
             p--;
         } while (--ct > 0);
 
-        free( (void*)pz );
         return res;
     }
 }
@@ -135,20 +127,20 @@ ag_scm_last_for_p( SCM which )
  *          Outside of any FOR loop, it returns SCM_UNDEFINED.
  *          @xref{FOR}.
 =*/
-    SCM
+SCM
 ag_scm_for_index( SCM which )
 {
     if (forInfo.fi_depth <= 0)
         return SCM_UNDEFINED;
+
     if (! gh_string_p( which ))
         return gh_int2scm( pFS->for_index );
 
     {
-        size_t     ct;
         tForState* p   = forInfo.fi_data + (forInfo.fi_depth - 1);
-        char*      pz  = gh_scm2newstr( which, &ct );
+        char*      pz  = ag_scm2zchars( which, "which for" );
         SCM        res = SCM_UNDEFINED;
-        ct = forInfo.fi_depth;
+        int        ct  = forInfo.fi_depth;
 
         do  {
             if (strcmp( p->for_pzName, pz ) == 0) {
@@ -158,7 +150,6 @@ ag_scm_for_index( SCM which )
             p--;
         } while (--ct > 0);
 
-        free( (void*)pz );
         return res;
     }
 }
@@ -174,7 +165,7 @@ ag_scm_for_index( SCM which )
  *       Outside of the FOR macro itself, this function will emit an error.
  *       @xref{FOR}.
 =*/
-    SCM
+SCM
 ag_scm_for_from( SCM from )
 {
     if ((! pFS->for_loading) || (! gh_number_p( from )))
@@ -194,7 +185,7 @@ ag_scm_for_from( SCM from )
  *       Outside of the FOR macro itself, this function will emit an error.
  *       @xref{FOR}.
 =*/
-    SCM
+SCM
 ag_scm_for_to( SCM to )
 {
     if ((! pFS->for_loading) || (! gh_number_p( to )))
@@ -214,7 +205,7 @@ ag_scm_for_to( SCM to )
  *       Outside of the FOR macro itself, this function will emit an error.
  *       @xref{FOR}.
 =*/
-    SCM
+SCM
 ag_scm_for_by( SCM by )
 {
     if ((! pFS->for_loading) || (! gh_number_p( by )))
@@ -235,7 +226,7 @@ ag_scm_for_by( SCM by )
  *       nothing more than a comma.
  *       Outside of the FOR macro itself, this function will emit an error.
 =*/
-    SCM
+SCM
 ag_scm_for_sep( SCM obj )
 {
     if (! pFS->for_loading)
@@ -303,11 +294,11 @@ doForByStep( tTemplate* pT,
              tMacro*    pMac,
              tDefEntry* pFoundDef )
 {
-    int         loopCt   = 0;
+    int         loopCt    = 0;
     tDefEntry   textDef;
     ag_bool     invert    = (pFS->for_by < 0);
     t_word      loopLimit = OPT_VALUE_LOOP_LIMIT;
-    tDefStack   stack     = currDefCtx;
+    tDefCtx     ctx       = currDefCtx;
 
     if (pFS->for_pzSep == NULL)
         pFS->for_pzSep = "";
@@ -386,7 +377,7 @@ doForByStep( tTemplate* pT,
          *  IF we have a non-base definition, use the old def context
          */
         if (! gotNewDef)
-            currDefCtx = stack;
+            currDefCtx = ctx;
 
         /*
          *  ELSE IF this macro is a text type
@@ -397,7 +388,7 @@ doForByStep( tTemplate* pT,
             textDef.pNext = textDef.pTwin = NULL;
 
             currDefCtx.pDefs = &textDef;
-            currDefCtx.pPrev = &stack;
+            currDefCtx.pPrev = &ctx;
         }
 
         /*
@@ -405,8 +396,8 @@ doForByStep( tTemplate* pT,
          *       macro's values
          */
         else {
-            currDefCtx.pDefs = (tDefEntry*)(void*)pFoundDef->pzValue;
-            currDefCtx.pPrev = &stack;
+            currDefCtx.pDefs = pFoundDef->val.pDefEntry;
+            currDefCtx.pPrev = &ctx;
         }
 
         pFS->for_lastFor = (invert)
@@ -426,7 +417,7 @@ doForByStep( tTemplate* pT,
         pFS->for_index = nextIdx;
     }
 
-    currDefCtx = stack;  /* Restore the def context */
+    currDefCtx = ctx;  /* Restore the def context */
     return loopCt;
 }
 
@@ -435,10 +426,10 @@ doForEach( tTemplate*   pT,
            tMacro*      pMac,
            tDefEntry*   pFoundDef )
 {
-    int loopCt = 0;
-    tDefStack   stack = currDefCtx;
+    int     loopCt = 0;
+    tDefCtx ctx    = currDefCtx;
 
-    currDefCtx.pPrev = &stack;
+    currDefCtx.pPrev = &ctx;
 
     for (;;) {
         tDefEntry  textDef;
@@ -456,7 +447,7 @@ doForEach( tTemplate*   pT,
 
             currDefCtx.pDefs = &textDef;
         } else {
-            currDefCtx.pDefs = (tDefEntry*)(void*)pFoundDef->pzValue;
+            currDefCtx.pDefs = pFoundDef->val.pDefEntry;
         }
 
         /*
@@ -487,7 +478,7 @@ doForEach( tTemplate*   pT,
         fflush( pCurFp->pFile );
     }
 
-    currDefCtx = stack;  /* Restore the def context */
+    currDefCtx = ctx;  /* Restore the def context */
     return loopCt;
 }
 
@@ -526,12 +517,11 @@ load_ForIn( tCC* pzSrc, int srcLen, tTemplate* pT, tMacro* pMac )
 
     do  {
         tDefEntry* pDef = getEntry();
-        int foundComma  = 0;
 
-        pDef->pzDefName = pzName;
-        pDef->index     = ix++;
-        pDef->valType   = VALTYP_TEXT;
-        pDef->pzValue   = pz;
+        pDef->pzDefName  = pzName;
+        pDef->index      = ix++;
+        pDef->valType    = VALTYP_TEXT;
+        pDef->val.pzText = pz;
 
         switch (*pz) {
         case '\'':
@@ -606,14 +596,10 @@ load_ForIn( tCC* pzSrc, int srcLen, tTemplate* pT, tMacro* pMac )
  *  This macro has a slight variation on the standard syntax:
  *  @example
  *  FOR <value-name> [ <separator-string> ]
- *  @end example
- *  or
- *  @example
- *  FOR <value-name> (...Scheme expression list
- *  @end example
- *  or
- *  @example
- *  FOR <value-name> IN "quoted string" unquoted-string ...
+ *
+ *  FOR <value-name> (...Scheme expression list)
+ *
+ *  FOR <value-name> IN "string" [ ... ]
  *  @end example
  *
  *  Other than for the last form, the first macro argument must be the name of
@@ -682,7 +668,7 @@ load_ForIn( tCC* pzSrc, int srcLen, tTemplate* pT, tMacro* pMac )
  *    This macro ends the @code{FOR} function template block.
  *    For a complete description @xref{FOR}.
 =*/
-    tMacro*
+tMacro*
 mFunc_For( tTemplate* pT, tMacro* pMac )
 {
     tMacro*     pMRet = pT->aMacros + pMac->endIndex;
@@ -755,9 +741,8 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
     return pMRet;
 }
 
-#endif /* DEFINE_LOAD_FUNCTIONS defined */
 
-    tMacro*
+tMacro*
 mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
     char*   pzCopy = pT->pNext; /* next text dest   */
@@ -854,7 +839,9 @@ mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 }
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of funcFor.c */
+ * end of agen5/funcFor.c */
