@@ -2,13 +2,13 @@
 /*
  *  tpParse.c
  *
- *  $Id: tpParse.c,v 1.19 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: tpParse.c,v 4.1 2005/01/01 00:12:34 bkorb Exp $
  *
  *  This module will load a template and return a template structure.
  */
 
 /*
- *  AutoGen copyright 1992-2003 Bruce Korb
+ *  AutoGen copyright 1992-2004 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -27,9 +27,6 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-#define LOAD_FUNCTIONS
-#include "autogen.h"
-
 STATIC teFuncType whichFunc( tCC** ppzScan );
 STATIC tCC* findMacroEnd( tCC** ppzMark );
 
@@ -131,8 +128,6 @@ findMacroEnd( tCC** ppzMark )
     tCC* pzMark = *ppzMark + startMacLen;
     tCC* pzNextMark;
     tCC* pzEndMark;
-    tSCC zOop[] = "Error:  a %s macro contains a nested macro\n";
-    char z[ 1024 ];
 
     /*
      *  Set our pointers to the start of the macro text
@@ -318,7 +313,9 @@ parseTemplate( tMacro* pM, tCC** ppzText )
 }
 /*
  * Local Variables:
+ * mode: C
  * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of tpParse.c */
+ * end of agen5/tpParse.c */
