@@ -1,15 +1,15 @@
 
 /*
- *  Time-stamp:      "2003-05-26 08:04:30 bkorb"
+ *  Time-stamp:      "2004-08-30 19:09:50 bkorb"
  *
- *  autoopts.h  $Id: autoopts.h,v 2.38 2003/05/31 22:59:15 bkorb Exp $
+ *  autoopts.h  $Id: autoopts.h,v 4.1 2005/01/01 00:12:40 bkorb Exp $
  *
  *  This file defines all the global structures and special values
  *  used in the automated option processing library.
  */
 
 /*
- *  Automated Options copyright 1992-2003 Bruce Korb
+ *  Automated Options copyright 1992-2004 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -63,8 +63,13 @@
 #include <time.h>
 #include <utime.h>
 
-#include "options.h"
-#include "streqv.h"
+#define AO_NAME_LIMIT    127
+#define AO_NAME_SIZE     (AO_NAME_LIMIT + 1)
+#ifndef MAXPATHLEN
+#  define MAXPATHLEN     4096
+#endif
+#undef  EXPORT
+#define EXPORT
 
 /*
  *  Convert the number to a list usable in a printf call
@@ -76,6 +81,12 @@
 
 #define SKIP_OPT(p)  (((p)->fOptState & (OPTST_DOCUMENT|OPTST_OMITTED)) != 0)
 
+typedef int tDirection;
+#define DIRECTION_PRESET  -1
+#define DIRECTION_PROCESS  1
+#define PROCESSING(d)     ((d)>0)
+#define PRESETTING(d)     ((d)<0)
+
 /*
  *  Procedure success codes
  *
@@ -127,8 +138,36 @@ typedef struct {
     tUL        flags;
     teOptType  optType;
     int        argType;
-    char*      pzOptArg;
+    tCC*       pzOptArg;
 } tOptState;
+#define OPTSTATE_INITIALIZER \
+    { NULL, OPTST_DEFINED, TOPT_UNDEFINED, 0, NULL }
+
+#define TEXTTO_TABLE \
+        _TT_( LONGUSAGE ) \
+        _TT_( USAGE ) \
+        _TT_( VERSION )
+#define _TT_(n) \
+        TT_ ## n ,
+
+typedef enum { TEXTTO_TABLE COUNT_TT } teTextTo;
+
+#undef _TT_
+
+typedef struct {
+    tCC*    pzStr;
+    tCC*    pzReq;
+    tCC*    pzNum;
+    tCC*    pzKey;
+    tCC*    pzKeyL;
+    tCC*    pzBool;
+    tCC*    pzOpt;
+    tCC*    pzNo;
+    tCC*    pzBrk;
+    tCC*    pzNoF;
+    tCC*    pzSpc;
+    tCC*    pzOptFmt;
+} arg_types_t;
 
 #  define AGALOC( c, w )        malloc( c )
 #  define AGREALOC( p, c, w )   realloc( p, c )
@@ -138,41 +177,140 @@ typedef struct {
 
 #ifdef AUTOGEN_BUILD
 #  include <snprintfv/printf.h>
-#else  /* NOT AUTOGEN_BUILD */
 #endif /* AUTOGEN_BUILD */
 
+/*
+ *  DO option handling?
+ *
+ *  Options are examined at two times:  at immediate handling time and at
+ *  normal handling time.  If an option is disabled, the timing may be
+ *  different from the handling of the undisabled option.  The OPTST_DIABLED
+ *  bit indicates the state of the currently discovered option.
+ *  So, here's how it works:
+ *
+ *  A) handling at "immediate" time, either 1 or 2:
+ *
+ *  1.  OPTST_DISABLED is not set:
+ *      IMM           must be set
+ *      DISABLE_IMM   don't care
+ *      TWICE         don't care
+ *      DISABLE_TWICE don't care
+ *      0 -and-  1 x x x
+ *
+ *  2.  OPTST_DISABLED is set:
+ *      IMM           don't care
+ *      DISABLE_IMM   must be set
+ *      TWICE         don't care
+ *      DISABLE_TWICE don't care
+ *      1 -and-  x 1 x x
+ */
+#define DO_IMMEDIATELY(_flg) \
+    (  (((_flg) & (OPTST_DISABLED|OPTST_IMM)) == OPTST_IMM) \
+    || (   ((_flg) & (OPTST_DISABLED|OPTST_DISABLE_IMM))    \
+        == (OPTST_DISABLED|OPTST_DISABLE_IMM)  ))
+
+/*  B) handling at "regular" time because it was not immediate
+ *
+ *  1.  OPTST_DISABLED is not set:
+ *      IMM           must *NOT* be set
+ *      DISABLE_IMM   don't care
+ *      TWICE         don't care
+ *      DISABLE_TWICE don't care
+ *      0 -and-  0 x x x
+ *
+ *  2.  OPTST_DISABLED is set:
+ *      IMM           don't care
+ *      DISABLE_IMM   don't care
+ *      TWICE         must be set
+ *      DISABLE_TWICE don't care
+ *      1 -and-  x x 1 x
+ */
+#define DO_NORMALLY(_flg) ( \
+       (((_flg) & (OPTST_DISABLED|OPTST_IMM))            == 0)  \
+    || (((_flg) & (OPTST_DISABLED|OPTST_DISABLE_IMM))    ==     \
+                  OPTST_DISABLED)  )
+
+/*  C)  handling at "regular" time because it is to be handled twice.
+ *      The immediate bit was already tested and found to be set:
+ *
+ *  3.  OPTST_DISABLED is not set:
+ *      IMM           is set (but don't care)
+ *      DISABLE_IMM   don't care
+ *      TWICE         must be set
+ *      DISABLE_TWICE don't care
+ *      0 -and-  ? x 1 x
+ *
+ *  4.  OPTST_DISABLED is set:
+ *      IMM           don't care
+ *      DISABLE_IMM   is set (but don't care)
+ *      TWICE         don't care
+ *      DISABLE_TWICE must be set
+ *      1 -and-  x ? x 1
+ */
+#define DO_SECOND_TIME(_flg) ( \
+       (((_flg) & (OPTST_DISABLED|OPTST_TWICE))          ==     \
+                  OPTST_TWICE)                                  \
+    || (((_flg) & (OPTST_DISABLED|OPTST_DISABLE_TWICE))  ==     \
+                  (OPTST_DISABLED|OPTST_DISABLE_TWICE)  ))
+
+/*
+ *  Define and initialize all the user visible strings.
+ *  We do not do translations.  If translations are to be done, then
+ *  the client will provide a callback for that purpose.
+ */
+#undef DO_TRANSLATIONS
+#include "usage-txt.h"
+
 /*
  *  File pointer for usage output
  */
 extern FILE* option_usage_fp;
 
-/*
- *  optionUsage print the usage text for the program described by the
- *  option descriptor.  Does not return.  Calls ``exit(3)'' with exitCode.
- */
-extern void optionUsage( tOptions*, int exitCode );
-
-/*
- *  optionSave saves the option state into an RC or INI file in
- *  the *LAST* defined directory in the papzHomeList.
- */
-extern void optionSave( tOptions* pOpts );
-
-/*
- *  optionMakePath  --  translate and construct a path
- *
- *  This routine does environment variable expansion if the first character
- *  is a ``$''.  If it starts with two dollar characters, then the path
- *  is relative to the location of the executable.
- */
-extern ag_bool optionMakePath(
-    char*    pzBuf,
-    size_t   bufSize,
-    tCC*     pzName,
-    tCC*     pzProgPath );
-
 extern tOptProc doVersion, doPagedUsage, doLoadOpt;
 
+#define LOCAL static
+#ifdef AUTOOPTS_INTERNAL
+/* === LOCAL PROCEDURES === */
+
+/* autoopts.c */
+static tSuccess
+handleOption( tOptions* pOpts, tOptState* pOptState );
+
+static tSuccess
+longOptionFind( tOptions* pOpts, char* pzOptName, tOptState* pOptState );
+
+static tSuccess
+shortOptionFind( tOptions* pOpts, tUC optValue, tOptState* pOptState );
+
+static tSuccess
+doImmediateOpts( tOptions* pOpts );
+
+static tSuccess
+doRegularOpts( tOptions* pOpts );
+
+
+/* environment.c */
+static void
+doPrognameEnv( tOptions* pOpts, teEnvPresetType type );
+
+static void
+doEnvPresets( tOptions* pOpts, teEnvPresetType type );
+
+
+/* load.c */
+static void
+filePreset(
+    tOptions*     pOpts,
+    const char*   pzFileName,
+    int           direction );
+
+
+/* sort.c */
+static void
+optionSort( tOptions* pOpts );
+
+/* === END LOCALS === */
+#endif /* GUILE_OPTIONS */
 #endif /* AUTOGEN_AUTOOPTS_H */
 /*
  * Local Variables:
