@@ -1,6 +1,6 @@
 
 /*
- *  $Id: streqv.h,v 2.14 2004/02/16 22:12:50 bkorb Exp $
+ *  $Id: streqv.h,v 4.1 2005/01/01 00:12:42 bkorb Exp $
  *
  *  String Equivalence
  *
@@ -55,6 +55,15 @@
 
 #ifndef TOOLS_STREQUIVALENCE
 #define TOOLS_STREQUIVALENCE
+/*
+ *  Hide the interface - it pollutes a POSIX claim
+ */
+#define strneqvcmp      option_strneqvcmp
+#define streqvcmp       option_streqvcmp
+#define equivalent      option_equivalent 
+#define strequate       option_strequate
+#define streqvmap       option_streqvmap
+#define strtransform    option_strtransform
 
 /* strneqvcmp
  *
